@@ -33,14 +33,19 @@ def list_tables(
     else:
         return [SQLResult(status="")]
 
+    # Fetch results before potentially executing another query
+    results = list(cur.fetchall()) if verbose and arg else cur
+
     if verbose and arg:
         query = f'SHOW CREATE TABLE {arg}'
         logger.debug(query)
         cur.execute(query)
         if one := cur.fetchone():
+            # Returning the SHOW CREATE TABLE as a "status" keeps it unformatted,
+            # which is a hack.  There should be an unformmatted_results argument.
             status = one[1]
 
-    return [SQLResult(results=cur, headers=headers, status=status)]
+    return [SQLResult(results=results, headers=headers, status=status)]
 
 
 @special_command("\\l", "\\l", "List databases.", arg_type=ArgType.RAW_QUERY, case_sensitive=True)
